@@ -146,28 +146,30 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_dynamodb
 import aws_cdk.aws_ec2
 import aws_cdk.aws_ecs
-import aws_cdk.core
+import constructs
 
 
 class FargateToDynamoDB(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-fargate-dynamodb.FargateToDynamoDB",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
+        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
         existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
@@ -179,7 +181,7 @@ class FargateToDynamoDB(
         table_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         table_environment_variable_name: typing.Optional[builtins.str] = None,
         table_permissions: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -201,6 +203,10 @@ class FargateToDynamoDB(
         :param table_permissions: Optional table permissions to grant to the Fargate service. One of the following may be specified: ``All``, ``Read``, ``ReadWrite``, ``Write``. Default: - 'ReadWrite'
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An DynamoDB Interface endpoint will be included in this VPC. Default: - none
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FargateToDynamoDB.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateToDynamoDBProps(
             public_api=public_api,
             cluster_props=cluster_props,
@@ -275,9 +281,9 @@ class FargateToDynamoDBProps:
         self,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
+        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
         existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
@@ -289,7 +295,7 @@ class FargateToDynamoDBProps:
         table_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         table_environment_variable_name: typing.Optional[builtins.str] = None,
         table_permissions: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - none
@@ -315,6 +321,24 @@ class FargateToDynamoDBProps:
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(FargateToDynamoDBProps.__init__)
+            check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
+            check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
+            check_type(argname="argument container_definition_props", value=container_definition_props, expected_type=type_hints["container_definition_props"])
+            check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
+            check_type(argname="argument ecr_image_version", value=ecr_image_version, expected_type=type_hints["ecr_image_version"])
+            check_type(argname="argument ecr_repository_arn", value=ecr_repository_arn, expected_type=type_hints["ecr_repository_arn"])
+            check_type(argname="argument existing_container_definition_object", value=existing_container_definition_object, expected_type=type_hints["existing_container_definition_object"])
+            check_type(argname="argument existing_fargate_service_object", value=existing_fargate_service_object, expected_type=type_hints["existing_fargate_service_object"])
+            check_type(argname="argument existing_table_interface", value=existing_table_interface, expected_type=type_hints["existing_table_interface"])
+            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
+            check_type(argname="argument fargate_service_props", value=fargate_service_props, expected_type=type_hints["fargate_service_props"])
+            check_type(argname="argument fargate_task_definition_props", value=fargate_task_definition_props, expected_type=type_hints["fargate_task_definition_props"])
+            check_type(argname="argument table_arn_environment_variable_name", value=table_arn_environment_variable_name, expected_type=type_hints["table_arn_environment_variable_name"])
+            check_type(argname="argument table_environment_variable_name", value=table_environment_variable_name, expected_type=type_hints["table_environment_variable_name"])
+            check_type(argname="argument table_permissions", value=table_permissions, expected_type=type_hints["table_permissions"])
+            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "public_api": public_api,
         }
