@@ -8,18 +8,17 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_dynamodb._jsii
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_ecs._jsii
-import aws_cdk.core._jsii
+from typeguard import check_type
+
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-fargate-dynamodb",
-    "1.157.0",
+    "2.13.0",
     __name__[0:-6],
-    "aws-fargate-dynamodb@1.157.0.jsii.tgz",
+    "aws-fargate-dynamodb@2.13.0.jsii.tgz",
 )
 
 __all__ = [
